@@ -18,6 +18,7 @@ from continuity.pt import PivotalTracker
 from getpass import getpass
 from os import chmod, rename
 from os.path import exists
+from requests.exceptions import ConnectionError
 from sys import exit
 
 
@@ -43,6 +44,9 @@ class GitCommand(BaseCommand):
 
         try:
             self.execute()
+        except (ConnectionError, GitException):
+            puts("fatal: unable to access remote.")
+            self.exit()
         except (KeyboardInterrupt, EOFError):
             puts()
             self.exit()
@@ -291,7 +295,7 @@ class InitCommand(GitCommand):
         for command, command_class in commands.iteritems():
             if issubclass(command_class, GitCommand):
                 alias = "continuity" if command == "init" else command
-                self.aliases[alias] = "!continuity {0} \"$@\"".format(command)
+                self.aliases[alias] = "!continuity {0}".format(command)
 
         self.git.set_configuration("continuity", **self.continuity)
         self.git.set_configuration("github", **self.github)
